@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-07-08 10:14:46
-@LastEditTime: 2020-08-11 11:47:31
-@LastEditors: HuangJingCan
-@Description: 
+:Author: HuangJingCan
+:Date: 2020-07-08 10:14:46
+:LastEditTime: 2020-12-25 10:25:04
+:LastEditors: HuangJingCan
+:Description: 
 """
 
 import http.client as httplib
