@@ -142,4 +142,13 @@ from seven_top.top.api.rest.OpenuidChangeRequest import OpenuidChangeRequest
 from seven_top.top.api.rest.SellercenterRoleInfoGetRequest import SellercenterRoleInfoGetRequest
 from seven_top.top.api.rest.SellercenterRolemembersGetRequest import SellercenterRolemembersGetRequest
 from seven_top.top.api.rest.SubuserEmployeeAddRequest import SubuserEmployeeAddRequest
-from seven_top.top.api.rest.JstSmsMessageBatchsendRequest import JstSmsMessageBatchsendRequest
\ No newline at end of file
+from seven_top.top.api.rest.JstSmsMessageBatchsendRequest import JstSmsMessageBatchsendRequest
+from seven_top.top.api.rest.JstMiniappCrowdCreateRequest import JstMiniappCrowdCreateRequest
+from seven_top.top.api.rest.JstMiniappCrowdMessageSendRequest import JstMiniappCrowdMessageSendRequest
+from seven_top.top.api.rest.JstMiniappOpenidMessageSendRequest import JstMiniappOpenidMessageSendRequest
+from seven_top.top.api.rest.MiniappAppSellerConfigCompleteRequest import MiniappAppSellerConfigCompleteRequest
+from seven_top.top.api.rest.AlibabaShopCouponApplyRequest import AlibabaShopCouponApplyRequest
+from seven_top.top.api.rest.AlibabaLafiteSellerActivityListRequest import AlibabaLafiteSellerActivityListRequest
+from seven_top.top.api.rest.AlibabaLatourStrategyShowRequest import AlibabaLatourStrategyShowRequest
+from seven_top.top.api.rest.AlibabaLafiteSellerBenefitListRequest import AlibabaLafiteSellerBenefitListRequest
+from seven_top.top.api.rest.AlibabaLatourStrategyIssueRequest import AlibabaLatourStrategyIssueRequest
\ No newline at end of file
